#
# spec file for package ghc-memory
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name memory
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.18.0
Release:        3.3
Summary:        Memory and related abstraction stuff
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-basement-devel
BuildRequires:  ghc-basement-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-foundation-devel
BuildRequires:  ghc-foundation-prof
%endif

%description
Chunk of memory, polymorphic byte array management and manipulation

* A polymorphic byte array abstraction and function similar to strict
ByteString.

* Different type of byte array abstraction.

* Raw memory IO operations (memory set, memory copy, ..)

* Aliasing with endianness support.

* Encoding : Base16, Base32, Base64.

* Hashing : FNV, SipHash.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Jan  8 2025 Peter Simons <psimons@suse.com>
- Update memory to version 0.18.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Sep  5 2022 Peter Simons <psimons@suse.com>
- Update memory to version 0.18.0.
  [#]# 0.18
  * drop support for ghc < 8.8
  * compat with ghc 9.4
  [#]# ...
* Thu Mar 10 2022 Peter Simons <psimons@suse.com>
- Update memory to version 0.17.0.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Sat Nov 20 2021 psimons@suse.com
- Update memory to version 0.16.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat May  8 2021 psimons@suse.com
- Update memory to version 0.16.0.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Mon Apr 26 2021 psimons@suse.com
- Update memory to version 0.15.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update memory to version 0.15.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Sep  6 2019 psimons@suse.com
- Update memory to version 0.15.0.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Thu Oct  4 2018 psimons@suse.com
- Update memory to version 0.14.18.
  [#]# 0.14.18
  * Branch/Release Snafu
  [#]# 0.14.17
  * Require basement >= 0.0.7, Fix compilation with GHC 8,6
  * Cleanup CPP, dropping support for much older version
* Fri Aug 17 2018 psimons@suse.com
- Update Cabal build information to prevent build attempts with
  GHC 8.6.x.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update memory to version 0.14.16.
  * Fix compilation with a newer basement (>= 0.0.7) and an older GHC (< 8.0)
  * Convert tests to foundation checks
  * Convert CI to haskell-ci
  * Fix compilation without foundation
  * Introduce ByteArrayL and associated method, as a type level sized version of ByteArray
  * Add NormalForm for Bytes and ScrubbedBytes
  * Fix bounds issues with empty strings in base64 and base32
  * Improve tests compatibility w.r.t old basement version
  * Handle compat SPECIALIZE for older GHC
  * Optimise copy operations and convert
  * Add instance of ByteArrayAccess and ByteArray for Block
  * Add Block and UArray in memory's tests
  * Fix issue in unBase64 with an empty bytestring that would cause a segfault
  * Reintroduce foundation compatibility with old version
  * Reduce dependency to basement
  * Fix incompatibility with foundation 0.0.14
  * Fix typo in state passing
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 0.14.6.
* Wed May  3 2017 psimons@suse.com
- Update to version 0.14.5 with cabal2obs.
* Tue Apr  4 2017 psimons@suse.com
- Update to version 0.14.3 with cabal2obs.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 0.14.2 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.14.1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.13 revision 0 with cabal2obs.
* Mon May 23 2016 mimi.vx@gmail.com
- update to 0.13
* Sun Apr 10 2016 mimi.vx@gmail.com
- update to 0.12
  * Fix compilation with mkWeak and latest GHC
* Fri Jan 15 2016 mimi.vx@gmail.com
- update 0.11
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.10
  * make memConstEqual more constant not using boolean comparaison
  * memConstEqual was comparing length times the first byte instead of comparing
    all the bytes one to one
  * Add Base64 variants
* Sat Jun  6 2015 mimi.vx@gmail.com
- update to 0.7
  * Fix fixed sized scrubber written too hastily, that would zero out memory, as
    the index was written through byte size, whereas the primitive would consider it
    as WordX type index. it would helps if Ghc.Prim had better documentation.
* Sun May 31 2015 mimi.vx@gmail.com
- initial commit
